# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/view/v1/view.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.archive.v1 import archive_pb2 as bilibili_dot_app_dot_archive_dot_v1_dot_archive__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x62ilibili/app/view/v1/view.proto\x12\x14\x62ilibili.app.view.v1\x1a\x19google/protobuf/any.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a%bilibili/app/archive/v1/archive.proto\"\xcf\x01\n\x10\x41\x63tivityResource\x12\x15\n\rmod_pool_name\x18\x01 \x01(\t\x12\x19\n\x11mod_resource_name\x18\x02 \x01(\t\x12\x10\n\x08\x62g_color\x18\x03 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x04 \x01(\t\x12\x12\n\ntext_color\x18\x05 \x01(\t\x12\x18\n\x10light_text_color\x18\x06 \x01(\t\x12\x17\n\x0f\x64\x61rk_text_color\x18\x07 \x01(\t\x12\x15\n\rdivider_color\x18\x08 \x01(\t\"\xb7\n\n\x0e\x41\x63tivitySeason\x12)\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12-\n\x05pages\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.view.v1.ViewPage\x12\x31\n\towner_ext\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.OnwerExt\x12/\n\x08req_user\x18\x04 \x01(\x0b\x32\x1d.bilibili.app.view.v1.ReqUser\x12\x31\n\telec_rank\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ElecRank\x12.\n\x07history\x18\x06 \x01(\x0b\x32\x1d.bilibili.app.view.v1.History\x12\x0c\n\x04\x62vid\x18\x07 \x01(\t\x12*\n\x05honor\x18\x08 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Honor\x12*\n\x05staff\x18\t \x03(\x0b\x32\x1b.bilibili.app.view.v1.Staff\x12\x33\n\nugc_season\x18\n \x01(\x0b\x32\x1f.bilibili.app.view.v1.UgcSeason\x12&\n\x03tab\x18\x0b \x01(\x0b\x32\x19.bilibili.app.view.v1.Tab\x12(\n\x04rank\x18\x0c \x01(\x0b\x32\x1a.bilibili.app.view.v1.Rank\x12*\n\x05order\x18\r \x01(\x0b\x32\x1b.bilibili.app.view.v1.Order\x12\x17\n\x0fsupport_dislike\x18\x0e \x01(\x08\x12?\n\x10operation_relate\x18\x0f \x01(\x0b\x32%.bilibili.app.view.v1.OperationRelate\x12\x41\n\x11\x61\x63tivity_resource\x18\x10 \x01(\x0b\x32&.bilibili.app.view.v1.ActivityResource\x12\x12\n\nshort_link\x18\x11 \x01(\t\x12*\n\x05label\x18\x12 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Label\x12.\n\x07\x64islike\x18\x13 \x01(\x0b\x32\x1d.bilibili.app.view.v1.Dislike\x12\x35\n\x0bplayer_icon\x18\x14 \x01(\x0b\x32 .bilibili.app.view.v1.PlayerIcon\x12\x16\n\x0eshare_subtitle\x18\x15 \x01(\t\x12\x31\n\tcm_config\x18\x16 \x01(\x0b\x32\x1e.bilibili.app.view.v1.CMConfig\x12\x44\n\x13tf_panel_customized\x18\x17 \x01(\x0b\x32\'.bilibili.app.view.v1.TFPanelCustomized\x12\x11\n\targue_msg\x18\x18 \x01(\t\x12*\n\x05\x65\x63ode\x18\x19 \x01(\x0e\x32\x1b.bilibili.app.view.v1.ECode\x12\x39\n\rcustom_config\x18\x1a \x01(\x0b\x32\".bilibili.app.view.v1.CustomConfig\x12\x11\n\tbadge_url\x18\x1b \x01(\t\x12-\n\x07\x64\x65sc_v2\x18\x1c \x03(\x0b\x32\x1c.bilibili.app.view.v1.DescV2\x12,\n\x06\x63onfig\x18\x1d \x01(\x0b\x32\x1c.bilibili.app.view.v1.Config\x12,\n\x06online\x18\x1e \x01(\x0b\x32\x1c.bilibili.app.view.v1.Online\"\x97\x01\n\x06\x41\x64Info\x12\x13\n\x0b\x63reative_id\x18\x01 \x01(\x03\x12\x15\n\rcreative_type\x18\x02 \x01(\x03\x12?\n\x10\x63reative_content\x18\x03 \x01(\x0b\x32%.bilibili.app.view.v1.CreativeContent\x12\r\n\x05\x61\x64_cb\x18\x04 \x01(\t\x12\x11\n\tcard_type\x18\x05 \x01(\x05\"<\n\x0e\x41\x64\x64\x43ontractReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0e\n\x06up_mid\x18\x02 \x01(\x03\x12\r\n\x05spmid\x18\x03 \x01(\t\"\x86\x01\n\x05\x41sset\x12\x0c\n\x04paid\x18\x01 \x01(\x05\x12\r\n\x05price\x18\x02 \x01(\x03\x12+\n\x03msg\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.AssetMsg\x12\x33\n\x0bpreview_msg\x18\x04 \x01(\x0b\x32\x1e.bilibili.app.view.v1.AssetMsg\"(\n\x08\x41ssetMsg\x12\r\n\x05\x64\x65sc1\x18\x01 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x02 \x01(\t\"O\n\tAttention\x12\x12\n\nstart_time\x18\x01 \x01(\x05\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\x05\x12\r\n\x05pos_x\x18\x03 \x01(\x01\x12\r\n\x05pos_y\x18\x04 \x01(\x01\"\x9a\x01\n\x05\x41udio\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tcover_url\x18\x02 \x01(\t\x12\x0f\n\x07song_id\x18\x03 \x01(\x03\x12\x12\n\nplay_count\x18\x04 \x01(\x03\x12\x13\n\x0breply_count\x18\x05 \x01(\x03\x12\x10\n\x08upper_id\x18\x06 \x01(\x03\x12\x10\n\x08\x65ntrance\x18\x07 \x01(\t\x12\x11\n\tsong_attr\x18\x08 \x01(\x03\"^\n\x03\x42gm\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x0f\n\x07jumpUrl\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\"&\n\x11\x42izFavSeasonParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"(\n\x13\x42izFollowVideoParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"\x1f\n\x10\x42izJumpLinkParam\x12\x0b\n\x03url\x18\x01 \x01(\t\"k\n\x17\x42izReserveActivityParam\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\x03\x12\x12\n\nreserve_id\x18\x05 \x01(\x03\"&\n\x13\x42izReserveGameParam\x12\x0f\n\x07game_id\x18\x01 \x01(\x03\"$\n\x06\x42utton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xb9\x01\n\x0e\x42uzzwordConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\r\n\x05start\x18\x04 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x03\x12\x16\n\x0e\x66ollow_control\x18\x06 \x01(\x08\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x13\n\x0b\x62uzzword_id\x18\x08 \x01(\x03\x12\x13\n\x0bschema_type\x18\t \x01(\x05\x12\x0f\n\x07picture\x18\n \x01(\t\"2\n\x02\x43M\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"5\n\x08\x43MConfig\x12)\n\x0b\x61\x64s_control\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\xf4\x04\n\x0e\x43\x61\x63heViewReply\x12)\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12-\n\x05pages\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.view.v1.ViewPage\x12\x31\n\towner_ext\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.OnwerExt\x12/\n\x08req_user\x18\x04 \x01(\x0b\x32\x1d.bilibili.app.view.v1.ReqUser\x12,\n\x06season\x18\x05 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Season\x12\x31\n\telec_rank\x18\x06 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ElecRank\x12.\n\x07history\x18\x07 \x01(\x0b\x32\x1d.bilibili.app.view.v1.History\x12.\n\x07\x64islike\x18\x08 \x01(\x0b\x32\x1d.bilibili.app.view.v1.Dislike\x12\x35\n\x0bplayer_icon\x18\t \x01(\x0b\x32 .bilibili.app.view.v1.PlayerIcon\x12\x0c\n\x04\x62vid\x18\n \x01(\t\x12\x12\n\nshort_link\x18\x0b \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x0c \x01(\t\x12\x44\n\x13tf_panel_customized\x18\r \x01(\x0b\x32\'.bilibili.app.view.v1.TFPanelCustomized\x12,\n\x06online\x18\x0e \x01(\x0b\x32\x1c.bilibili.app.view.v1.Online\"}\n\x0c\x43\x61\x63heViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0f\n\x07trackid\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x05 \x01(\t\x12\r\n\x05spmid\x18\x06 \x01(\t\x12\x12\n\nfrom_spmid\x18\x07 \x01(\t\"2\n\x07\x43hronos\x12\x0b\n\x03md5\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\"V\n\rChronosPkgReq\x12\x13\n\x0bservice_key\x18\x01 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x02 \x01(\t\x12\x18\n\x10message_protocol\x18\x03 \x01(\t\"\xfa\x01\n\x16\x43lickActivitySeasonReq\x12\x31\n\norder_type\x18\x01 \x01(\x0e\x32\x1d.bilibili.app.view.v1.BizType\x12\r\n\x05spmid\x18\x02 \x01(\t\x12@\n\x07reserve\x18\x03 \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x00\x12=\n\nfav_season\x18\x04 \x01(\x0b\x32\'.bilibili.app.view.v1.BizFavSeasonParamH\x00\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x03\x42\r\n\x0border_param\"Y\n\x12\x43lickPlayerCardReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\x03\x12\r\n\x05spmid\x18\x05 \x01(\t\"\xab\x01\n\x06\x43mIpad\x12$\n\x02\x63m\x18\x01 \x01(\x0b\x32\x18.bilibili.app.view.v1.CM\x12/\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12+\n\x04stat\x18\x03 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x0b\n\x03\x61id\x18\x05 \x01(\x03\"\xa1\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\r\n\x05idStr\x18\n \x01(\t\"\xfc\x01\n\x06\x43onfig\x12\x15\n\rrelates_title\x18\x01 \x01(\t\x12\x15\n\rrelates_style\x18\x02 \x01(\x05\x12\x16\n\x0erelate_gif_exp\x18\x03 \x01(\x05\x12\x15\n\rend_page_half\x18\x04 \x01(\x05\x12\x15\n\rend_page_full\x18\x05 \x01(\x05\x12\x14\n\x0c\x61uto_swindow\x18\x06 \x01(\x08\x12\x12\n\npopup_info\x18\x07 \x01(\x08\x12\x1b\n\x13\x61\x62test_small_window\x18\x08 \x01(\t\x12\x1d\n\x15rec_three_point_style\x18\t \x01(\x05\x12\x18\n\x10is_absolute_time\x18\n \x01(\x08\"\xbe\x02\n\x0c\x43ontractCard\x12\x18\n\x10\x64isplay_progress\x18\x01 \x01(\x02\x12\x18\n\x10\x64isplay_accuracy\x18\x02 \x01(\x03\x12\x18\n\x10\x64isplay_duration\x18\x03 \x01(\x03\x12\x11\n\tshow_mode\x18\x04 \x01(\x05\x12\x11\n\tpage_type\x18\x05 \x01(\x05\x12/\n\x05upper\x18\x06 \x01(\x0b\x32 .bilibili.app.view.v1.UpperInfos\x12\x19\n\x11is_follow_display\x18\x07 \x01(\x05\x12\x30\n\x04text\x18\x08 \x01(\x0b\x32\".bilibili.app.view.v1.ContractText\x12#\n\x1b\x66ollow_display_end_duration\x18\t \x01(\x03\x12\x17\n\x0fis_play_display\x18\n \x01(\x05\"E\n\x0c\x43ontractText\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x14\n\x0cinline_title\x18\x03 \x01(\t\"\xe9\x01\n\x0f\x43reativeContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x03 \x01(\t\x12\x10\n\x08video_id\x18\x04 \x01(\x03\x12\x10\n\x08username\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x11\n\timage_md5\x18\x07 \x01(\t\x12\x0f\n\x07log_url\x18\x08 \x01(\t\x12\x0f\n\x07log_md5\x18\t \x01(\t\x12\x0b\n\x03url\x18\n \x01(\t\x12\x11\n\tclick_url\x18\x0b \x01(\t\x12\x10\n\x08show_url\x18\x0c \x01(\t\"$\n\x0c\x43ustomConfig\x12\x14\n\x0credirect_url\x18\x01 \x01(\t\"6\n\x02\x44M\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x11\n\treal_name\x18\x02 \x01(\x08\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\"^\n\x06\x44\x65scV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x1e.bilibili.app.view.v1.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0b\n\x03rid\x18\x04 \x01(\x03\"a\n\x07\x44islike\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x35\n\x07reasons\x18\x03 \x03(\x0b\x32$.bilibili.app.view.v1.DislikeReasons\"T\n\x0e\x44islikeReasons\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x05\x12\x0e\n\x06tag_id\x18\x04 \x01(\x03\x12\x0c\n\x04name\x18\x05 \x01(\t\"K\n\x08\x45lecRank\x12\x30\n\x04list\x18\x01 \x03(\x0b\x32\".bilibili.app.view.v1.ElecRankItem\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"N\n\x0c\x45lecRankItem\x12\x0e\n\x06\x61vatar\x18\x01 \x01(\t\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0b\n\x03mid\x18\x04 \x01(\x03\"\x93\x02\n\x07\x45pisode\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x16\n\x0e\x63overRightText\x18\x06 \x01(\t\x12+\n\x04page\x18\x07 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Page\x12+\n\x04stat\x18\x08 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x0c\n\x04\x62vid\x18\t \x01(\t\x12/\n\x06\x61uthor\x18\n \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12\x13\n\x0b\x61uthor_desc\x18\x0b \x01(\t\"w\n\x13\x45xposePlayerCardReq\x12\x37\n\tcard_type\x18\x01 \x01(\x0e\x32$.bilibili.app.view.v1.PlayerCardType\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\r\n\x05spmid\x18\x04 \x01(\t\"j\n\x0c\x46\x65\x65\x64ViewItem\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.view.v1.ViewReply\x12\x0c\n\x04goto\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08track_id\x18\x04 \x01(\t\"S\n\rFeedViewReply\x12\x30\n\x04list\x18\x01 \x03(\x0b\x32\".bilibili.app.view.v1.FeedViewItem\x12\x10\n\x08has_next\x18\x02 \x01(\x08\"\xf3\x01\n\x0b\x46\x65\x65\x64ViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x12\n\nfrom_spmid\x18\x05 \x01(\t\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\ndisplay_id\x18\x07 \x01(\x03\x12\x12\n\nsession_id\x18\x08 \x01(\t\x12\x14\n\x0cpage_version\x18\t \x01(\t\x12\x15\n\rfrom_track_id\x18\n \x01(\t\"(\n\x07History\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x03\"\xc2\x01\n\x05Honor\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_night\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x12\n\ntext_extra\x18\x04 \x01(\t\x12\x12\n\ntext_color\x18\x05 \x01(\t\x12\x18\n\x10text_color_night\x18\x06 \x01(\t\x12\x10\n\x08\x62g_color\x18\x07 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x10\n\x08url_text\x18\n \x01(\t\"\x85\x01\n\x0bInteraction\x12\x30\n\x0chistory_node\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.view.v1.Node\x12\x15\n\rgraph_version\x18\x02 \x01(\x03\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x12\n\nevaluation\x18\x04 \x01(\t\x12\x0c\n\x04mark\x18\x05 \x01(\x03\"m\n\x05Label\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nicon_night\x18\x04 \x01(\t\x12\x12\n\nicon_width\x18\x05 \x01(\x03\x12\x13\n\x0bicon_height\x18\x06 \x01(\x03\"q\n\nLikeCustom\x12\x13\n\x0blike_switch\x18\x01 \x01(\x08\x12\x1d\n\x15\x66ull_to_half_progress\x18\x02 \x01(\x03\x12\x19\n\x11non_full_progress\x18\x03 \x01(\x03\x12\x14\n\x0cupdate_count\x18\x04 \x01(\x03\"E\n\x04Live\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0e\n\x06roomid\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ndpage_uri\x18\x04 \x01(\t\"[\n\rLiveOrderInfo\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x1c\n\x14live_plan_start_time\x18\x03 \x01(\x03\x12\x11\n\tis_follow\x18\x04 \x01(\x08\"\t\n\x07NoReply\"3\n\x04Node\x12\x0f\n\x07node_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"%\n\x06Notice\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"9\n\x06Online\x12\x13\n\x0bonline_show\x18\x01 \x01(\x08\x12\x1a\n\x12player_online_logo\x18\x02 \x01(\t\"\xcd\x01\n\x08OnwerExt\x12=\n\x0fofficial_verify\x18\x01 \x01(\x0b\x32$.bilibili.app.view.v1.OfficialVerify\x12(\n\x04live\x18\x02 \x01(\x0b\x32\x1a.bilibili.app.view.v1.Live\x12&\n\x03vip\x18\x03 \x01(\x0b\x32\x19.bilibili.app.view.v1.Vip\x12\x0f\n\x07\x61ssists\x18\x04 \x03(\x03\x12\x0c\n\x04\x66\x61ns\x18\x05 \x01(\x03\x12\x11\n\tarc_count\x18\x06 \x01(\t\"\x85\x01\n\rOperationCard\x12\x12\n\nstart_time\x18\x01 \x01(\x05\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\x05\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\"\xa7\x04\n\x10OperationCardNew\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\x12\n\n\x02to\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\x08\x12:\n\tcard_type\x18\x05 \x01(\x0e\x32\'.bilibili.app.view.v1.OperationCardType\x12\x36\n\x08standard\x18\x06 \x01(\x0b\x32\".bilibili.app.view.v1.StandardCardH\x00\x12\x33\n\x04skip\x18\x07 \x01(\x0b\x32#.bilibili.app.view.v1.OperationCardH\x00\x12/\n\x08\x62iz_type\x18\x08 \x01(\x0e\x32\x1d.bilibili.app.view.v1.BizType\x12;\n\x06\x66ollow\x18\t \x01(\x0b\x32).bilibili.app.view.v1.BizFollowVideoParamH\x01\x12@\n\x07reserve\x18\n \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x01\x12\x36\n\x04jump\x18\x0b \x01(\x0b\x32&.bilibili.app.view.v1.BizJumpLinkParamH\x01\x12\x39\n\x04game\x18\x0c \x01(\x0b\x32).bilibili.app.view.v1.BizReserveGameParamH\x01\x42\x08\n\x06renderB\x07\n\x05param\"\x8d\x01\n\x0fOperationRelate\x12\r\n\x05title\x18\x01 \x01(\t\x12\x35\n\x0brelate_item\x18\x02 \x03(\x0b\x32 .bilibili.app.view.v1.RelateItem\x12\x34\n\x0e\x61i_relate_item\x18\x03 \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\"\xe4\x02\n\x05Order\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\r\n\x05title\x18\x02 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x03 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x04 \x01(\t\x12\x18\n\x10season_stat_view\x18\x05 \x01(\x03\x12\x1b\n\x13season_stat_danmaku\x18\x06 \x01(\x03\x12\x31\n\norder_type\x18\x07 \x01(\x0e\x32\x1d.bilibili.app.view.v1.BizType\x12@\n\x07reserve\x18\x08 \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x00\x12=\n\nfav_season\x18\t \x01(\x0b\x32\'.bilibili.app.view.v1.BizFavSeasonParamH\x00\x12\r\n\x05intro\x18\n \x01(\tB\r\n\x0border_param\"&\n\x08PackInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"F\n\nPlayerIcon\x12\x0c\n\x04url1\x18\x01 \x01(\t\x12\r\n\x05hash1\x18\x02 \x01(\t\x12\x0c\n\x04url2\x18\x03 \x01(\t\x12\r\n\x05hash2\x18\x04 \x01(\t\"5\n\rPointMaterial\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x17\n\x0fmaterial_source\x18\x02 \x01(\x05\"6\n\x04Rank\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_night\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xc9\x01\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x10\n\x08\x62g_color\x18\x03 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x04 \x01(\t\x12\x18\n\x10text_color_night\x18\x05 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08selected\x18\t \x01(\x05\"\xda\x01\n\nRecDislike\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\x12\x18\n\x10\x63losed_sub_title\x18\x03 \x01(\t\x12\x12\n\npaste_text\x18\x04 \x01(\t\x12\x19\n\x11\x63losed_paste_text\x18\x05 \x01(\t\x12<\n\x0e\x64islike_reason\x18\x06 \x03(\x0b\x32$.bilibili.app.view.v1.DislikeReasons\x12\r\n\x05toast\x18\x07 \x01(\t\x12\x14\n\x0c\x63losed_toast\x18\x08 \x01(\t\"\x8b\x01\n\rRecThreePoint\x12\x31\n\x07\x64islike\x18\x01 \x01(\x0b\x32 .bilibili.app.view.v1.RecDislike\x12\x32\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\x0b\x32 .bilibili.app.view.v1.RecDislike\x12\x13\n\x0bwatch_later\x18\x03 \x01(\x08\"\xca\x06\n\x06Relate\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03pic\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12/\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12+\n\x04stat\x18\x05 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\x0c\n\x04goto\x18\x07 \x01(\t\x12\r\n\x05param\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\x12\x10\n\x08jump_url\x18\n \x01(\t\x12\x0e\n\x06rating\x18\x0b \x01(\x01\x12\x0f\n\x07reserve\x18\x0c \x01(\t\x12\x0c\n\x04\x66rom\x18\r \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0e \x01(\t\x12\x13\n\x0brcmd_reason\x18\x0f \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x10 \x01(\t\x12\x0b\n\x03\x63id\x18\x11 \x01(\x03\x12\x13\n\x0bseason_type\x18\x12 \x01(\x05\x12\x14\n\x0crating_count\x18\x13 \x01(\x05\x12\x10\n\x08tag_name\x18\x14 \x01(\t\x12\x31\n\tpack_info\x18\x15 \x01(\x0b\x32\x1e.bilibili.app.view.v1.PackInfo\x12,\n\x06notice\x18\x16 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Notice\x12,\n\x06\x62utton\x18\x17 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Button\x12\x0f\n\x07trackid\x18\x18 \x01(\t\x12\x10\n\x08new_card\x18\x19 \x01(\x05\x12<\n\x11rcmd_reason_style\x18\x1a \x01(\x0b\x32!.bilibili.app.view.v1.ReasonStyle\x12\x11\n\tcover_gif\x18\x1b \x01(\t\x12$\n\x02\x63m\x18\x1c \x01(\x0b\x32\x18.bilibili.app.view.v1.CM\x12\x16\n\x0ereserve_status\x18\x1d \x01(\x03\x12\x19\n\x11rcmd_reason_extra\x18\x1e \x01(\t\x12<\n\x0frec_three_point\x18\x1f \x01(\x0b\x32#.bilibili.app.view.v1.RecThreePoint\x12\x11\n\tunique_id\x18  \x01(\t\x12\x13\n\x0bmaterial_id\x18! \x01(\x03\"(\n\nRelateItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\"&\n\tRelateTab\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\xa1\x01\n\x07ReqUser\x12\x11\n\tattention\x18\x01 \x01(\x05\x12\x17\n\x0fguest_attention\x18\x02 \x01(\x05\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x05\x12\x0c\n\x04like\x18\x04 \x01(\x05\x12\x0f\n\x07\x64islike\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\x17\n\x0f\x61ttention_level\x18\x07 \x01(\x05\x12\x12\n\nfav_season\x18\x08 \x01(\x05\"`\n\x0bRestriction\x12\x14\n\x0cis_teenagers\x18\x01 \x01(\x08\x12\x12\n\nis_lessons\x18\x02 \x01(\x08\x12\x11\n\tis_review\x18\x03 \x01(\x08\x12\x14\n\x0c\x64isable_rcmd\x18\x04 \x01(\x08\"\xca\x02\n\x06Season\x12\x16\n\x0e\x61llow_download\x18\x01 \x01(\t\x12\x11\n\tseason_id\x18\x02 \x01(\x03\x12\x0f\n\x07is_jump\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x11\n\tis_finish\x18\x06 \x01(\x05\x12\x14\n\x0cnewest_ep_id\x18\x07 \x01(\x03\x12\x17\n\x0fnewest_ep_index\x18\x08 \x01(\t\x12\x13\n\x0btotal_count\x18\t \x01(\x03\x12\x0f\n\x07weekday\x18\n \x01(\x05\x12\x35\n\x0buser_season\x18\x0b \x01(\x0b\x32 .bilibili.app.view.v1.UserSeason\x12\x32\n\x06player\x18\x0c \x01(\x0b\x32\".bilibili.app.view.v1.SeasonPlayer\x12\x13\n\x0bogv_playurl\x18\r \x01(\t\"C\n\x0cSeasonPlayer\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03vid\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x04 \x01(\t\">\n\x0bSeasonReply\x12/\n\x06season\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.view.v1.UgcSeason\"\x1e\n\tSeasonReq\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"c\n\x07Section\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12/\n\x08\x65pisodes\x18\x04 \x03(\x0b\x32\x1d.bilibili.app.view.v1.Episode\"\x85\x01\n\x1bShortFormVideoDownloadReply\x12\x18\n\x10has_download_url\x18\x01 \x01(\x08\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\x12\x0b\n\x03md5\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12\x1b\n\x13\x62\x61\x63kup_download_url\x18\x05 \x01(\t\"\xeb\x01\n\x19ShortFormVideoDownloadReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\r\n\x05\x62uvid\x18\x04 \x01(\t\x12\x10\n\x08mobi_app\x18\x05 \x01(\t\x12\r\n\x05\x62uild\x18\x06 \x01(\x03\x12\x0e\n\x06\x64\x65vice\x18\x07 \x01(\t\x12\x10\n\x08platform\x18\x08 \x01(\t\x12\r\n\x05spmid\x18\t \x01(\t\x12\x36\n\x0brestriction\x18\n \x01(\x0b\x32!.bilibili.app.view.v1.Restriction\x12\x0e\n\x06tf_isp\x18\x0b \x01(\t\"\xf8\x01\n\x0bSpecialCell\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_night\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x12\n\ntext_color\x18\x04 \x01(\t\x12\x18\n\x10text_color_night\x18\x05 \x01(\t\x12\x10\n\x08jump_url\x18\x06 \x01(\t\x12\x11\n\tcell_type\x18\x07 \x01(\t\x12\x14\n\x0c\x63\x65ll_bgcolor\x18\x08 \x01(\t\x12\x1a\n\x12\x63\x65ll_bgcolor_night\x18\t \x01(\t\x12\r\n\x05param\x18\n \x01(\t\x12\x12\n\npage_title\x18\x0b \x01(\t\x12\x11\n\tjump_type\x18\x0c \x01(\t\"\xce\x01\n\x05Staff\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12=\n\x0fofficial_verify\x18\x05 \x01(\x0b\x32$.bilibili.app.view.v1.OfficialVerify\x12&\n\x03vip\x18\x06 \x01(\x0b\x32\x19.bilibili.app.view.v1.Vip\x12\x11\n\tattention\x18\x07 \x01(\x05\x12\x13\n\x0blabel_style\x18\x08 \x01(\x05\"i\n\x0cStandardCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x02 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x03 \x01(\t\x12\x15\n\rshow_selected\x18\x04 \x01(\x08\"\xbb\x02\n\x11TFPanelCustomized\x12\x15\n\rright_btn_img\x18\x01 \x01(\t\x12\x16\n\x0eright_btn_text\x18\x02 \x01(\t\x12\x1c\n\x14right_btn_text_color\x18\x03 \x01(\t\x12\x16\n\x0eright_btn_link\x18\x04 \x01(\t\x12\x12\n\nmain_label\x18\x05 \x01(\t\x12\x10\n\x08operator\x18\x06 \x01(\t\x12H\n\tsub_panel\x18\x07 \x03(\x0b\x32\x35.bilibili.app.view.v1.TFPanelCustomized.SubPanelEntry\x1aQ\n\rSubPanelEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .bilibili.app.view.v1.subTFPanel:\x02\x38\x01\"\x15\n\x05TIcon\x12\x0c\n\x04icon\x18\x01 \x01(\t\"\x94\x02\n\x03Tab\x12\x12\n\nbackground\x18\x01 \x01(\t\x12-\n\x05otype\x18\x02 \x01(\x0e\x32\x1e.bilibili.app.view.v1.TabOtype\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12-\n\x05style\x18\x05 \x01(\x0e\x32\x1e.bilibili.app.view.v1.TabStyle\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x12\n\ntext_color\x18\x07 \x01(\t\x12\x1b\n\x13text_color_selected\x18\x08 \x01(\t\x12\x0b\n\x03pic\x18\t \x01(\t\x12\n\n\x02id\x18\n \x01(\x03\x12)\n\x0b\x61\x64_tab_info\x18\x0b \x01(\x0b\x32\x14.google.protobuf.Any\"z\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05likes\x18\x03 \x01(\x03\x12\r\n\x05hates\x18\x04 \x01(\x03\x12\r\n\x05liked\x18\x05 \x01(\x05\x12\r\n\x05hated\x18\x06 \x01(\x05\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x10\n\x08tag_type\x18\x08 \x01(\t\"\xa7\x03\n\tUgcSeason\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05intro\x18\x04 \x01(\t\x12/\n\x08sections\x18\x05 \x03(\x0b\x32\x1d.bilibili.app.view.v1.Section\x12\x31\n\x04stat\x18\x06 \x01(\x0b\x32#.bilibili.app.view.v1.UgcSeasonStat\x12\x12\n\nlabel_text\x18\x07 \x01(\t\x12\x18\n\x10label_text_color\x18\x08 \x01(\t\x12\x16\n\x0elabel_bg_color\x18\t \x01(\t\x12\x1e\n\x16label_text_night_color\x18\n \x01(\t\x12\x1c\n\x14label_bg_night_color\x18\x0b \x01(\t\x12\x11\n\tdescRight\x18\x0c \x01(\t\x12\x10\n\x08\x65p_count\x18\r \x01(\x03\x12\x35\n\x0bseason_type\x18\x0e \x01(\x0e\x32 .bilibili.app.view.v1.SeasonType\x12\x1d\n\x15show_continual_button\x18\x0f \x01(\x08\"\xac\x01\n\rUgcSeasonStat\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\"o\n\x05UpAct\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tstatement\x18\x04 \x01(\t\x12\r\n\x05image\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x0e\n\x06\x62utton\x18\x07 \x01(\t\">\n\tUpLikeImg\x12\x0f\n\x07pre_img\x18\x01 \x01(\t\x12\x0f\n\x07suc_img\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"t\n\nUpperInfos\x12\x12\n\nfans_count\x18\x01 \x01(\x03\x12 \n\x18\x61rc_count_last_half_year\x18\x02 \x01(\x03\x12\x16\n\x0e\x66irst_up_dates\x18\x03 \x01(\x03\x12\x18\n\x10total_play_count\x18\x04 \x01(\x03\"%\n\x08UserGarb\x12\x19\n\x11url_image_ani_cut\x18\x01 \x01(\t\"\x1f\n\nUserSeason\x12\x11\n\tattention\x18\x01 \x01(\t\"\xb1\x02\n\nVideoGuide\x12\x32\n\tattention\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.view.v1.Attention\x12\x33\n\ncommandDms\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.view.v1.CommandDm\x12;\n\x0eoperation_card\x18\x03 \x03(\x0b\x32#.bilibili.app.view.v1.OperationCard\x12\x42\n\x12operation_card_new\x18\x04 \x03(\x0b\x32&.bilibili.app.view.v1.OperationCardNew\x12\x39\n\rcontract_card\x18\x05 \x01(\x0b\x32\".bilibili.app.view.v1.ContractCard\"f\n\nVideoPoint\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x03\x12\n\n\x02to\x18\x03 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08logo_url\x18\x06 \x01(\t\"y\n\tVideoShot\x12\x0f\n\x07pv_data\x18\x01 \x01(\t\x12\x11\n\timg_x_len\x18\x02 \x01(\x05\x12\x11\n\timg_y_len\x18\x03 \x01(\x05\x12\x12\n\nimg_x_size\x18\x04 \x01(\x05\x12\x12\n\nimg_y_size\x18\x05 \x01(\x05\x12\r\n\x05image\x18\x06 \x03(\t\"Y\n\x0cViewMaterial\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\"\xbc\x01\n\x08ViewPage\x12+\n\x04page\x18\x01 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Page\x12*\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Audio\x12$\n\x02\x64m\x18\x03 \x01(\x0b\x32\x18.bilibili.app.view.v1.DM\x12\x16\n\x0e\x64ownload_title\x18\x04 \x01(\t\x12\x19\n\x11\x64ownload_subtitle\x18\x05 \x01(\t\"\xf5\x02\n\x11ViewProgressReply\x12\x35\n\x0bvideo_guide\x18\x01 \x01(\x0b\x32 .bilibili.app.view.v1.VideoGuide\x12.\n\x07\x63hronos\x18\x02 \x01(\x0b\x32\x1d.bilibili.app.view.v1.Chronos\x12\x31\n\x08\x61rc_shot\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.view.v1.VideoShot\x12\x30\n\x06points\x18\x04 \x03(\x0b\x32 .bilibili.app.view.v1.VideoPoint\x12;\n\x0epoint_material\x18\x05 \x01(\x0b\x32#.bilibili.app.view.v1.PointMaterial\x12\x17\n\x0fpoint_permanent\x18\x06 \x01(\x08\x12>\n\x10\x62uzzword_periods\x18\x07 \x03(\x0b\x32$.bilibili.app.view.v1.BuzzwordConfig\"\x82\x01\n\x0fViewProgressReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x16\n\x0e\x65ngine_version\x18\x04 \x01(\t\x12\x18\n\x10message_protocol\x18\x05 \x01(\t\x12\x13\n\x0bservice_key\x18\x06 \x01(\t\"\xb2\x11\n\tViewReply\x12)\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12-\n\x05pages\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.view.v1.ViewPage\x12\x31\n\towner_ext\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.OnwerExt\x12/\n\x08req_user\x18\x04 \x01(\x0b\x32\x1d.bilibili.app.view.v1.ReqUser\x12&\n\x03tag\x18\x05 \x03(\x0b\x32\x19.bilibili.app.view.v1.Tag\x12:\n\x06t_icon\x18\x06 \x03(\x0b\x32*.bilibili.app.view.v1.ViewReply.TIconEntry\x12,\n\x06season\x18\x07 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Season\x12\x31\n\telec_rank\x18\x08 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ElecRank\x12.\n\x07history\x18\t \x01(\x0b\x32\x1d.bilibili.app.view.v1.History\x12-\n\x07relates\x18\n \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\x12.\n\x07\x64islike\x18\x0b \x01(\x0b\x32\x1d.bilibili.app.view.v1.Dislike\x12\x35\n\x0bplayer_icon\x18\x0c \x01(\x0b\x32 .bilibili.app.view.v1.PlayerIcon\x12\x12\n\nvip_active\x18\r \x01(\t\x12\x0c\n\x04\x62vid\x18\x0e \x01(\t\x12*\n\x05honor\x18\x0f \x01(\x0b\x32\x1b.bilibili.app.view.v1.Honor\x12\x33\n\nrelate_tab\x18\x10 \x03(\x0b\x32\x1f.bilibili.app.view.v1.RelateTab\x12\x14\n\x0c\x61\x63tivity_url\x18\x11 \x01(\t\x12&\n\x03\x62gm\x18\x12 \x03(\x0b\x32\x19.bilibili.app.view.v1.Bgm\x12*\n\x05staff\x18\x13 \x03(\x0b\x32\x1b.bilibili.app.view.v1.Staff\x12\x11\n\targue_msg\x18\x14 \x01(\t\x12\x12\n\nshort_link\x18\x15 \x01(\t\x12\x12\n\nplay_param\x18\x16 \x01(\x05\x12*\n\x05label\x18\x17 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Label\x12\x33\n\nugc_season\x18\x18 \x01(\x0b\x32\x1f.bilibili.app.view.v1.UgcSeason\x12,\n\x06\x63onfig\x18\x19 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Config\x12\x16\n\x0eshare_subtitle\x18\x1a \x01(\t\x12\x36\n\x0binteraction\x18\x1b \x01(\x0b\x32!.bilibili.app.view.v1.Interaction\x12*\n\x05\x65\x63ode\x18\x1c \x01(\x0e\x32\x1b.bilibili.app.view.v1.ECode\x12\x39\n\rcustom_config\x18\x1d \x01(\x0b\x32\".bilibili.app.view.v1.CustomConfig\x12%\n\x03\x63ms\x18\x1e \x03(\x0b\x32\x18.bilibili.app.view.v1.CM\x12\x31\n\tcm_config\x18\x1f \x01(\x0b\x32\x1e.bilibili.app.view.v1.CMConfig\x12&\n\x03tab\x18  \x01(\x0b\x32\x19.bilibili.app.view.v1.Tab\x12(\n\x04rank\x18! \x01(\x0b\x32\x1a.bilibili.app.view.v1.Rank\x12\x44\n\x13tf_panel_customized\x18\" \x01(\x0b\x32\'.bilibili.app.view.v1.TFPanelCustomized\x12+\n\x06up_act\x18# \x01(\x0b\x32\x1b.bilibili.app.view.v1.UpAct\x12\x31\n\tuser_garb\x18$ \x01(\x0b\x32\x1e.bilibili.app.view.v1.UserGarb\x12=\n\x0f\x61\x63tivity_season\x18% \x01(\x0b\x32$.bilibili.app.view.v1.ActivitySeason\x12\x11\n\tbadge_url\x18& \x01(\t\x12<\n\x0flive_order_info\x18\' \x01(\x0b\x32#.bilibili.app.view.v1.LiveOrderInfo\x12-\n\x07\x64\x65sc_v2\x18( \x03(\x0b\x32\x1c.bilibili.app.view.v1.DescV2\x12-\n\x07\x63m_ipad\x18) \x01(\x0b\x32\x1c.bilibili.app.view.v1.CmIpad\x12\x33\n\x07sticker\x18* \x03(\x0b\x32\".bilibili.app.view.v1.ViewMaterial\x12\x34\n\x0bup_like_img\x18+ \x01(\x0b\x32\x1f.bilibili.app.view.v1.UpLikeImg\x12\x35\n\x0blike_custom\x18, \x01(\x0b\x32 .bilibili.app.view.v1.LikeCustom\x12+\n\x08\x64\x65sc_tag\x18- \x03(\x0b\x32\x19.bilibili.app.view.v1.Tag\x12\x37\n\x0cspecial_cell\x18. \x01(\x0b\x32!.bilibili.app.view.v1.SpecialCell\x12,\n\x06online\x18/ \x01(\x0b\x32\x1c.bilibili.app.view.v1.Online\x12-\n\x0f\x63m_under_player\x18\x30 \x01(\x0b\x32\x14.google.protobuf.Any\x1aI\n\nTIconEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.view.v1.TIcon:\x02\x38\x01\"\xda\x02\n\x07ViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0f\n\x07trackid\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x05 \x01(\t\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\x12\r\n\x05spmid\x18\x0b \x01(\t\x12\x12\n\nfrom_spmid\x18\x0c \x01(\t\x12\x10\n\x08\x61utoplay\x18\r \x01(\x05\x12\x43\n\x0bplayer_args\x18\x0e \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0cpage_version\x18\x0f \x01(\t\x12\x11\n\tbiz_extra\x18\x10 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x11 \x01(\x03\"\xc0\x01\n\x03Vip\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x02 \x01(\x03\x12\x12\n\ndue_remark\x18\x03 \x01(\t\x12\x15\n\raccess_status\x18\x04 \x01(\x05\x12\x12\n\nvip_status\x18\x05 \x01(\x05\x12\x17\n\x0fvip_status_warn\x18\x06 \x01(\t\x12\x12\n\ntheme_type\x18\x07 \x01(\x05\x12-\n\x05label\x18\x08 \x01(\x0b\x32\x1e.bilibili.app.view.v1.VipLabel\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\"\x97\x01\n\nsubTFPanel\x12\x15\n\rright_btn_img\x18\x01 \x01(\t\x12\x16\n\x0eright_btn_text\x18\x02 \x01(\t\x12\x1c\n\x14right_btn_text_color\x18\x03 \x01(\t\x12\x16\n\x0eright_btn_link\x18\x04 \x01(\t\x12\x12\n\nmain_label\x18\x05 \x01(\t\x12\x10\n\x08operator\x18\x06 \x01(\t*\x91\x01\n\x07\x42izType\x12\x0f\n\x0b\x42izTypeNone\x10\x00\x12\x16\n\x12\x42izTypeFollowVideo\x10\x01\x12\x1a\n\x16\x42izTypeReserveActivity\x10\x02\x12\x13\n\x0f\x42izTypeJumpLink\x10\x03\x12\x14\n\x10\x42izTypeFavSeason\x10\x04\x12\x16\n\x12\x42izTypeReserveGame\x10\x05*A\n\x08\x44\x65scType\x12\x13\n\x0f\x44\x65scTypeUnknown\x10\x00\x12\x10\n\x0c\x44\x65scTypeText\x10\x01\x12\x0e\n\nDescTypeAt\x10\x02*!\n\x05\x45\x43ode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07\x43ODE404\x10\x01*)\n\x0eMaterialSource\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\n\n\x06\x42iJian\x10\x01*M\n\x11OperationCardType\x12\x10\n\x0c\x43\x61rdTypeNone\x10\x00\x12\x14\n\x10\x43\x61rdTypeStandard\x10\x01\x12\x10\n\x0c\x43\x61rdTypeSkip\x10\x02*\x96\x01\n\x0ePlayerCardType\x12\x1c\n\x18PlayerCardTypeNone_VALUE\x10\x00\x12!\n\x1dPlayerCardTypeAttention_VALUE\x10\x01\x12!\n\x1dPlayerCardTypeOperation_VALUE\x10\x02\x12 \n\x1cPlayerCardTypeContract_VALUE\x10\x03*-\n\nSeasonType\x12\x0b\n\x07Unknown\x10\x00\x12\x08\n\x04\x42\x61se\x10\x01\x12\x08\n\x04Good\x10\x02*2\n\x08TabOtype\x12\x10\n\x0cUnknownOtype\x10\x00\x12\x07\n\x03URL\x10\x01\x12\x0b\n\x07TopicNA\x10\x02*/\n\x08TabStyle\x12\x10\n\x0cUnknownStyle\x10\x00\x12\x08\n\x04Text\x10\x01\x12\x07\n\x03Pic\x10\x02\x32\xe9\x07\n\x04View\x12\x46\n\x04View\x12\x1d.bilibili.app.view.v1.ViewReq\x1a\x1f.bilibili.app.view.v1.ViewReply\x12^\n\x0cViewProgress\x12%.bilibili.app.view.v1.ViewProgressReq\x1a\'.bilibili.app.view.v1.ViewProgressReply\x12|\n\x16ShortFormVideoDownload\x12/.bilibili.app.view.v1.ShortFormVideoDownloadReq\x1a\x31.bilibili.app.view.v1.ShortFormVideoDownloadReply\x12Z\n\x0f\x43lickPlayerCard\x12(.bilibili.app.view.v1.ClickPlayerCardReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12\x62\n\x13\x43lickActivitySeason\x12,.bilibili.app.view.v1.ClickActivitySeasonReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12L\n\x06Season\x12\x1f.bilibili.app.view.v1.SeasonReq\x1a!.bilibili.app.view.v1.SeasonReply\x12\\\n\x10\x45xposePlayerCard\x12).bilibili.app.view.v1.ExposePlayerCardReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12R\n\x0b\x41\x64\x64\x43ontract\x12$.bilibili.app.view.v1.AddContractReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12R\n\x08\x46\x65\x65\x64View\x12!.bilibili.app.view.v1.FeedViewReq\x1a#.bilibili.app.view.v1.FeedViewReply\x12P\n\nChronosPkg\x12#.bilibili.app.view.v1.ChronosPkgReq\x1a\x1d.bilibili.app.view.v1.Chronos\x12U\n\tCacheView\x12\".bilibili.app.view.v1.CacheViewReq\x1a$.bilibili.app.view.v1.CacheViewReplyb\x06proto3')

_BIZTYPE = DESCRIPTOR.enum_types_by_name['BizType']
BizType = enum_type_wrapper.EnumTypeWrapper(_BIZTYPE)
_DESCTYPE = DESCRIPTOR.enum_types_by_name['DescType']
DescType = enum_type_wrapper.EnumTypeWrapper(_DESCTYPE)
_ECODE = DESCRIPTOR.enum_types_by_name['ECode']
ECode = enum_type_wrapper.EnumTypeWrapper(_ECODE)
_MATERIALSOURCE = DESCRIPTOR.enum_types_by_name['MaterialSource']
MaterialSource = enum_type_wrapper.EnumTypeWrapper(_MATERIALSOURCE)
_OPERATIONCARDTYPE = DESCRIPTOR.enum_types_by_name['OperationCardType']
OperationCardType = enum_type_wrapper.EnumTypeWrapper(_OPERATIONCARDTYPE)
_PLAYERCARDTYPE = DESCRIPTOR.enum_types_by_name['PlayerCardType']
PlayerCardType = enum_type_wrapper.EnumTypeWrapper(_PLAYERCARDTYPE)
_SEASONTYPE = DESCRIPTOR.enum_types_by_name['SeasonType']
SeasonType = enum_type_wrapper.EnumTypeWrapper(_SEASONTYPE)
_TABOTYPE = DESCRIPTOR.enum_types_by_name['TabOtype']
TabOtype = enum_type_wrapper.EnumTypeWrapper(_TABOTYPE)
_TABSTYLE = DESCRIPTOR.enum_types_by_name['TabStyle']
TabStyle = enum_type_wrapper.EnumTypeWrapper(_TABSTYLE)
BizTypeNone = 0
BizTypeFollowVideo = 1
BizTypeReserveActivity = 2
BizTypeJumpLink = 3
BizTypeFavSeason = 4
BizTypeReserveGame = 5
DescTypeUnknown = 0
DescTypeText = 1
DescTypeAt = 2
DEFAULT = 0
CODE404 = 1
Default = 0
BiJian = 1
CardTypeNone = 0
CardTypeStandard = 1
CardTypeSkip = 2
PlayerCardTypeNone_VALUE = 0
PlayerCardTypeAttention_VALUE = 1
PlayerCardTypeOperation_VALUE = 2
PlayerCardTypeContract_VALUE = 3
Unknown = 0
Base = 1
Good = 2
UnknownOtype = 0
URL = 1
TopicNA = 2
UnknownStyle = 0
Text = 1
Pic = 2


_ACTIVITYRESOURCE = DESCRIPTOR.message_types_by_name['ActivityResource']
_ACTIVITYSEASON = DESCRIPTOR.message_types_by_name['ActivitySeason']
_ADINFO = DESCRIPTOR.message_types_by_name['AdInfo']
_ADDCONTRACTREQ = DESCRIPTOR.message_types_by_name['AddContractReq']
_ASSET = DESCRIPTOR.message_types_by_name['Asset']
_ASSETMSG = DESCRIPTOR.message_types_by_name['AssetMsg']
_ATTENTION = DESCRIPTOR.message_types_by_name['Attention']
_AUDIO = DESCRIPTOR.message_types_by_name['Audio']
_BGM = DESCRIPTOR.message_types_by_name['Bgm']
_BIZFAVSEASONPARAM = DESCRIPTOR.message_types_by_name['BizFavSeasonParam']
_BIZFOLLOWVIDEOPARAM = DESCRIPTOR.message_types_by_name['BizFollowVideoParam']
_BIZJUMPLINKPARAM = DESCRIPTOR.message_types_by_name['BizJumpLinkParam']
_BIZRESERVEACTIVITYPARAM = DESCRIPTOR.message_types_by_name['BizReserveActivityParam']
_BIZRESERVEGAMEPARAM = DESCRIPTOR.message_types_by_name['BizReserveGameParam']
_BUTTON = DESCRIPTOR.message_types_by_name['Button']
_BUZZWORDCONFIG = DESCRIPTOR.message_types_by_name['BuzzwordConfig']
_CM = DESCRIPTOR.message_types_by_name['CM']
_CMCONFIG = DESCRIPTOR.message_types_by_name['CMConfig']
_CACHEVIEWREPLY = DESCRIPTOR.message_types_by_name['CacheViewReply']
_CACHEVIEWREQ = DESCRIPTOR.message_types_by_name['CacheViewReq']
_CHRONOS = DESCRIPTOR.message_types_by_name['Chronos']
_CHRONOSPKGREQ = DESCRIPTOR.message_types_by_name['ChronosPkgReq']
_CLICKACTIVITYSEASONREQ = DESCRIPTOR.message_types_by_name['ClickActivitySeasonReq']
_CLICKPLAYERCARDREQ = DESCRIPTOR.message_types_by_name['ClickPlayerCardReq']
_CMIPAD = DESCRIPTOR.message_types_by_name['CmIpad']
_COMMANDDM = DESCRIPTOR.message_types_by_name['CommandDm']
_CONFIG = DESCRIPTOR.message_types_by_name['Config']
_CONTRACTCARD = DESCRIPTOR.message_types_by_name['ContractCard']
_CONTRACTTEXT = DESCRIPTOR.message_types_by_name['ContractText']
_CREATIVECONTENT = DESCRIPTOR.message_types_by_name['CreativeContent']
_CUSTOMCONFIG = DESCRIPTOR.message_types_by_name['CustomConfig']
_DM = DESCRIPTOR.message_types_by_name['DM']
_DESCV2 = DESCRIPTOR.message_types_by_name['DescV2']
_DISLIKE = DESCRIPTOR.message_types_by_name['Dislike']
_DISLIKEREASONS = DESCRIPTOR.message_types_by_name['DislikeReasons']
_ELECRANK = DESCRIPTOR.message_types_by_name['ElecRank']
_ELECRANKITEM = DESCRIPTOR.message_types_by_name['ElecRankItem']
_EPISODE = DESCRIPTOR.message_types_by_name['Episode']
_EXPOSEPLAYERCARDREQ = DESCRIPTOR.message_types_by_name['ExposePlayerCardReq']
_FEEDVIEWITEM = DESCRIPTOR.message_types_by_name['FeedViewItem']
_FEEDVIEWREPLY = DESCRIPTOR.message_types_by_name['FeedViewReply']
_FEEDVIEWREQ = DESCRIPTOR.message_types_by_name['FeedViewReq']
_HISTORY = DESCRIPTOR.message_types_by_name['History']
_HONOR = DESCRIPTOR.message_types_by_name['Honor']
_INTERACTION = DESCRIPTOR.message_types_by_name['Interaction']
_LABEL = DESCRIPTOR.message_types_by_name['Label']
_LIKECUSTOM = DESCRIPTOR.message_types_by_name['LikeCustom']
_LIVE = DESCRIPTOR.message_types_by_name['Live']
_LIVEORDERINFO = DESCRIPTOR.message_types_by_name['LiveOrderInfo']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_NODE = DESCRIPTOR.message_types_by_name['Node']
_NOTICE = DESCRIPTOR.message_types_by_name['Notice']
_OFFICIALVERIFY = DESCRIPTOR.message_types_by_name['OfficialVerify']
_ONLINE = DESCRIPTOR.message_types_by_name['Online']
_ONWEREXT = DESCRIPTOR.message_types_by_name['OnwerExt']
_OPERATIONCARD = DESCRIPTOR.message_types_by_name['OperationCard']
_OPERATIONCARDNEW = DESCRIPTOR.message_types_by_name['OperationCardNew']
_OPERATIONRELATE = DESCRIPTOR.message_types_by_name['OperationRelate']
_ORDER = DESCRIPTOR.message_types_by_name['Order']
_PACKINFO = DESCRIPTOR.message_types_by_name['PackInfo']
_PLAYERICON = DESCRIPTOR.message_types_by_name['PlayerIcon']
_POINTMATERIAL = DESCRIPTOR.message_types_by_name['PointMaterial']
_RANK = DESCRIPTOR.message_types_by_name['Rank']
_REASONSTYLE = DESCRIPTOR.message_types_by_name['ReasonStyle']
_RECDISLIKE = DESCRIPTOR.message_types_by_name['RecDislike']
_RECTHREEPOINT = DESCRIPTOR.message_types_by_name['RecThreePoint']
_RELATE = DESCRIPTOR.message_types_by_name['Relate']
_RELATEITEM = DESCRIPTOR.message_types_by_name['RelateItem']
_RELATETAB = DESCRIPTOR.message_types_by_name['RelateTab']
_REQUSER = DESCRIPTOR.message_types_by_name['ReqUser']
_RESTRICTION = DESCRIPTOR.message_types_by_name['Restriction']
_SEASON = DESCRIPTOR.message_types_by_name['Season']
_SEASONPLAYER = DESCRIPTOR.message_types_by_name['SeasonPlayer']
_SEASONREPLY = DESCRIPTOR.message_types_by_name['SeasonReply']
_SEASONREQ = DESCRIPTOR.message_types_by_name['SeasonReq']
_SECTION = DESCRIPTOR.message_types_by_name['Section']
_SHORTFORMVIDEODOWNLOADREPLY = DESCRIPTOR.message_types_by_name['ShortFormVideoDownloadReply']
_SHORTFORMVIDEODOWNLOADREQ = DESCRIPTOR.message_types_by_name['ShortFormVideoDownloadReq']
_SPECIALCELL = DESCRIPTOR.message_types_by_name['SpecialCell']
_STAFF = DESCRIPTOR.message_types_by_name['Staff']
_STANDARDCARD = DESCRIPTOR.message_types_by_name['StandardCard']
_TFPANELCUSTOMIZED = DESCRIPTOR.message_types_by_name['TFPanelCustomized']
_TFPANELCUSTOMIZED_SUBPANELENTRY = _TFPANELCUSTOMIZED.nested_types_by_name['SubPanelEntry']
_TICON = DESCRIPTOR.message_types_by_name['TIcon']
_TAB = DESCRIPTOR.message_types_by_name['Tab']
_TAG = DESCRIPTOR.message_types_by_name['Tag']
_UGCSEASON = DESCRIPTOR.message_types_by_name['UgcSeason']
_UGCSEASONSTAT = DESCRIPTOR.message_types_by_name['UgcSeasonStat']
_UPACT = DESCRIPTOR.message_types_by_name['UpAct']
_UPLIKEIMG = DESCRIPTOR.message_types_by_name['UpLikeImg']
_UPPERINFOS = DESCRIPTOR.message_types_by_name['UpperInfos']
_USERGARB = DESCRIPTOR.message_types_by_name['UserGarb']
_USERSEASON = DESCRIPTOR.message_types_by_name['UserSeason']
_VIDEOGUIDE = DESCRIPTOR.message_types_by_name['VideoGuide']
_VIDEOPOINT = DESCRIPTOR.message_types_by_name['VideoPoint']
_VIDEOSHOT = DESCRIPTOR.message_types_by_name['VideoShot']
_VIEWMATERIAL = DESCRIPTOR.message_types_by_name['ViewMaterial']
_VIEWPAGE = DESCRIPTOR.message_types_by_name['ViewPage']
_VIEWPROGRESSREPLY = DESCRIPTOR.message_types_by_name['ViewProgressReply']
_VIEWPROGRESSREQ = DESCRIPTOR.message_types_by_name['ViewProgressReq']
_VIEWREPLY = DESCRIPTOR.message_types_by_name['ViewReply']
_VIEWREPLY_TICONENTRY = _VIEWREPLY.nested_types_by_name['TIconEntry']
_VIEWREQ = DESCRIPTOR.message_types_by_name['ViewReq']
_VIP = DESCRIPTOR.message_types_by_name['Vip']
_VIPLABEL = DESCRIPTOR.message_types_by_name['VipLabel']
_SUBTFPANEL = DESCRIPTOR.message_types_by_name['subTFPanel']
ActivityResource = _reflection.GeneratedProtocolMessageType('ActivityResource', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYRESOURCE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ActivityResource)
  })
_sym_db.RegisterMessage(ActivityResource)

ActivitySeason = _reflection.GeneratedProtocolMessageType('ActivitySeason', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSEASON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ActivitySeason)
  })
_sym_db.RegisterMessage(ActivitySeason)

AdInfo = _reflection.GeneratedProtocolMessageType('AdInfo', (_message.Message,), {
  'DESCRIPTOR' : _ADINFO,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.AdInfo)
  })
_sym_db.RegisterMessage(AdInfo)

AddContractReq = _reflection.GeneratedProtocolMessageType('AddContractReq', (_message.Message,), {
  'DESCRIPTOR' : _ADDCONTRACTREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.AddContractReq)
  })
_sym_db.RegisterMessage(AddContractReq)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Asset)
  })
_sym_db.RegisterMessage(Asset)

AssetMsg = _reflection.GeneratedProtocolMessageType('AssetMsg', (_message.Message,), {
  'DESCRIPTOR' : _ASSETMSG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.AssetMsg)
  })
_sym_db.RegisterMessage(AssetMsg)

Attention = _reflection.GeneratedProtocolMessageType('Attention', (_message.Message,), {
  'DESCRIPTOR' : _ATTENTION,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Attention)
  })
_sym_db.RegisterMessage(Attention)

Audio = _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {
  'DESCRIPTOR' : _AUDIO,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Audio)
  })
_sym_db.RegisterMessage(Audio)

Bgm = _reflection.GeneratedProtocolMessageType('Bgm', (_message.Message,), {
  'DESCRIPTOR' : _BGM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Bgm)
  })
_sym_db.RegisterMessage(Bgm)

BizFavSeasonParam = _reflection.GeneratedProtocolMessageType('BizFavSeasonParam', (_message.Message,), {
  'DESCRIPTOR' : _BIZFAVSEASONPARAM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.BizFavSeasonParam)
  })
_sym_db.RegisterMessage(BizFavSeasonParam)

BizFollowVideoParam = _reflection.GeneratedProtocolMessageType('BizFollowVideoParam', (_message.Message,), {
  'DESCRIPTOR' : _BIZFOLLOWVIDEOPARAM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.BizFollowVideoParam)
  })
_sym_db.RegisterMessage(BizFollowVideoParam)

BizJumpLinkParam = _reflection.GeneratedProtocolMessageType('BizJumpLinkParam', (_message.Message,), {
  'DESCRIPTOR' : _BIZJUMPLINKPARAM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.BizJumpLinkParam)
  })
_sym_db.RegisterMessage(BizJumpLinkParam)

BizReserveActivityParam = _reflection.GeneratedProtocolMessageType('BizReserveActivityParam', (_message.Message,), {
  'DESCRIPTOR' : _BIZRESERVEACTIVITYPARAM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.BizReserveActivityParam)
  })
_sym_db.RegisterMessage(BizReserveActivityParam)

BizReserveGameParam = _reflection.GeneratedProtocolMessageType('BizReserveGameParam', (_message.Message,), {
  'DESCRIPTOR' : _BIZRESERVEGAMEPARAM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.BizReserveGameParam)
  })
_sym_db.RegisterMessage(BizReserveGameParam)

Button = _reflection.GeneratedProtocolMessageType('Button', (_message.Message,), {
  'DESCRIPTOR' : _BUTTON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Button)
  })
_sym_db.RegisterMessage(Button)

BuzzwordConfig = _reflection.GeneratedProtocolMessageType('BuzzwordConfig', (_message.Message,), {
  'DESCRIPTOR' : _BUZZWORDCONFIG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.BuzzwordConfig)
  })
_sym_db.RegisterMessage(BuzzwordConfig)

CM = _reflection.GeneratedProtocolMessageType('CM', (_message.Message,), {
  'DESCRIPTOR' : _CM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CM)
  })
_sym_db.RegisterMessage(CM)

CMConfig = _reflection.GeneratedProtocolMessageType('CMConfig', (_message.Message,), {
  'DESCRIPTOR' : _CMCONFIG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CMConfig)
  })
_sym_db.RegisterMessage(CMConfig)

CacheViewReply = _reflection.GeneratedProtocolMessageType('CacheViewReply', (_message.Message,), {
  'DESCRIPTOR' : _CACHEVIEWREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CacheViewReply)
  })
_sym_db.RegisterMessage(CacheViewReply)

CacheViewReq = _reflection.GeneratedProtocolMessageType('CacheViewReq', (_message.Message,), {
  'DESCRIPTOR' : _CACHEVIEWREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CacheViewReq)
  })
_sym_db.RegisterMessage(CacheViewReq)

Chronos = _reflection.GeneratedProtocolMessageType('Chronos', (_message.Message,), {
  'DESCRIPTOR' : _CHRONOS,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Chronos)
  })
_sym_db.RegisterMessage(Chronos)

ChronosPkgReq = _reflection.GeneratedProtocolMessageType('ChronosPkgReq', (_message.Message,), {
  'DESCRIPTOR' : _CHRONOSPKGREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ChronosPkgReq)
  })
_sym_db.RegisterMessage(ChronosPkgReq)

ClickActivitySeasonReq = _reflection.GeneratedProtocolMessageType('ClickActivitySeasonReq', (_message.Message,), {
  'DESCRIPTOR' : _CLICKACTIVITYSEASONREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ClickActivitySeasonReq)
  })
_sym_db.RegisterMessage(ClickActivitySeasonReq)

ClickPlayerCardReq = _reflection.GeneratedProtocolMessageType('ClickPlayerCardReq', (_message.Message,), {
  'DESCRIPTOR' : _CLICKPLAYERCARDREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ClickPlayerCardReq)
  })
_sym_db.RegisterMessage(ClickPlayerCardReq)

CmIpad = _reflection.GeneratedProtocolMessageType('CmIpad', (_message.Message,), {
  'DESCRIPTOR' : _CMIPAD,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CmIpad)
  })
_sym_db.RegisterMessage(CmIpad)

CommandDm = _reflection.GeneratedProtocolMessageType('CommandDm', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CommandDm)
  })
_sym_db.RegisterMessage(CommandDm)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Config)
  })
_sym_db.RegisterMessage(Config)

ContractCard = _reflection.GeneratedProtocolMessageType('ContractCard', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTCARD,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ContractCard)
  })
_sym_db.RegisterMessage(ContractCard)

ContractText = _reflection.GeneratedProtocolMessageType('ContractText', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTTEXT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ContractText)
  })
_sym_db.RegisterMessage(ContractText)

CreativeContent = _reflection.GeneratedProtocolMessageType('CreativeContent', (_message.Message,), {
  'DESCRIPTOR' : _CREATIVECONTENT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CreativeContent)
  })
_sym_db.RegisterMessage(CreativeContent)

CustomConfig = _reflection.GeneratedProtocolMessageType('CustomConfig', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMCONFIG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.CustomConfig)
  })
_sym_db.RegisterMessage(CustomConfig)

DM = _reflection.GeneratedProtocolMessageType('DM', (_message.Message,), {
  'DESCRIPTOR' : _DM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.DM)
  })
_sym_db.RegisterMessage(DM)

DescV2 = _reflection.GeneratedProtocolMessageType('DescV2', (_message.Message,), {
  'DESCRIPTOR' : _DESCV2,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.DescV2)
  })
_sym_db.RegisterMessage(DescV2)

Dislike = _reflection.GeneratedProtocolMessageType('Dislike', (_message.Message,), {
  'DESCRIPTOR' : _DISLIKE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Dislike)
  })
_sym_db.RegisterMessage(Dislike)

DislikeReasons = _reflection.GeneratedProtocolMessageType('DislikeReasons', (_message.Message,), {
  'DESCRIPTOR' : _DISLIKEREASONS,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.DislikeReasons)
  })
_sym_db.RegisterMessage(DislikeReasons)

ElecRank = _reflection.GeneratedProtocolMessageType('ElecRank', (_message.Message,), {
  'DESCRIPTOR' : _ELECRANK,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ElecRank)
  })
_sym_db.RegisterMessage(ElecRank)

ElecRankItem = _reflection.GeneratedProtocolMessageType('ElecRankItem', (_message.Message,), {
  'DESCRIPTOR' : _ELECRANKITEM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ElecRankItem)
  })
_sym_db.RegisterMessage(ElecRankItem)

Episode = _reflection.GeneratedProtocolMessageType('Episode', (_message.Message,), {
  'DESCRIPTOR' : _EPISODE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Episode)
  })
_sym_db.RegisterMessage(Episode)

ExposePlayerCardReq = _reflection.GeneratedProtocolMessageType('ExposePlayerCardReq', (_message.Message,), {
  'DESCRIPTOR' : _EXPOSEPLAYERCARDREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ExposePlayerCardReq)
  })
_sym_db.RegisterMessage(ExposePlayerCardReq)

FeedViewItem = _reflection.GeneratedProtocolMessageType('FeedViewItem', (_message.Message,), {
  'DESCRIPTOR' : _FEEDVIEWITEM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.FeedViewItem)
  })
_sym_db.RegisterMessage(FeedViewItem)

FeedViewReply = _reflection.GeneratedProtocolMessageType('FeedViewReply', (_message.Message,), {
  'DESCRIPTOR' : _FEEDVIEWREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.FeedViewReply)
  })
_sym_db.RegisterMessage(FeedViewReply)

FeedViewReq = _reflection.GeneratedProtocolMessageType('FeedViewReq', (_message.Message,), {
  'DESCRIPTOR' : _FEEDVIEWREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.FeedViewReq)
  })
_sym_db.RegisterMessage(FeedViewReq)

History = _reflection.GeneratedProtocolMessageType('History', (_message.Message,), {
  'DESCRIPTOR' : _HISTORY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.History)
  })
_sym_db.RegisterMessage(History)

Honor = _reflection.GeneratedProtocolMessageType('Honor', (_message.Message,), {
  'DESCRIPTOR' : _HONOR,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Honor)
  })
_sym_db.RegisterMessage(Honor)

Interaction = _reflection.GeneratedProtocolMessageType('Interaction', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTION,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Interaction)
  })
_sym_db.RegisterMessage(Interaction)

Label = _reflection.GeneratedProtocolMessageType('Label', (_message.Message,), {
  'DESCRIPTOR' : _LABEL,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Label)
  })
_sym_db.RegisterMessage(Label)

LikeCustom = _reflection.GeneratedProtocolMessageType('LikeCustom', (_message.Message,), {
  'DESCRIPTOR' : _LIKECUSTOM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.LikeCustom)
  })
_sym_db.RegisterMessage(LikeCustom)

Live = _reflection.GeneratedProtocolMessageType('Live', (_message.Message,), {
  'DESCRIPTOR' : _LIVE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Live)
  })
_sym_db.RegisterMessage(Live)

LiveOrderInfo = _reflection.GeneratedProtocolMessageType('LiveOrderInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVEORDERINFO,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.LiveOrderInfo)
  })
_sym_db.RegisterMessage(LiveOrderInfo)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Node)
  })
_sym_db.RegisterMessage(Node)

Notice = _reflection.GeneratedProtocolMessageType('Notice', (_message.Message,), {
  'DESCRIPTOR' : _NOTICE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Notice)
  })
_sym_db.RegisterMessage(Notice)

OfficialVerify = _reflection.GeneratedProtocolMessageType('OfficialVerify', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALVERIFY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.OfficialVerify)
  })
_sym_db.RegisterMessage(OfficialVerify)

Online = _reflection.GeneratedProtocolMessageType('Online', (_message.Message,), {
  'DESCRIPTOR' : _ONLINE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Online)
  })
_sym_db.RegisterMessage(Online)

OnwerExt = _reflection.GeneratedProtocolMessageType('OnwerExt', (_message.Message,), {
  'DESCRIPTOR' : _ONWEREXT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.OnwerExt)
  })
_sym_db.RegisterMessage(OnwerExt)

OperationCard = _reflection.GeneratedProtocolMessageType('OperationCard', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONCARD,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.OperationCard)
  })
_sym_db.RegisterMessage(OperationCard)

OperationCardNew = _reflection.GeneratedProtocolMessageType('OperationCardNew', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONCARDNEW,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.OperationCardNew)
  })
_sym_db.RegisterMessage(OperationCardNew)

OperationRelate = _reflection.GeneratedProtocolMessageType('OperationRelate', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONRELATE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.OperationRelate)
  })
_sym_db.RegisterMessage(OperationRelate)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Order)
  })
_sym_db.RegisterMessage(Order)

PackInfo = _reflection.GeneratedProtocolMessageType('PackInfo', (_message.Message,), {
  'DESCRIPTOR' : _PACKINFO,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.PackInfo)
  })
_sym_db.RegisterMessage(PackInfo)

PlayerIcon = _reflection.GeneratedProtocolMessageType('PlayerIcon', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERICON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.PlayerIcon)
  })
_sym_db.RegisterMessage(PlayerIcon)

PointMaterial = _reflection.GeneratedProtocolMessageType('PointMaterial', (_message.Message,), {
  'DESCRIPTOR' : _POINTMATERIAL,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.PointMaterial)
  })
_sym_db.RegisterMessage(PointMaterial)

Rank = _reflection.GeneratedProtocolMessageType('Rank', (_message.Message,), {
  'DESCRIPTOR' : _RANK,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Rank)
  })
_sym_db.RegisterMessage(Rank)

ReasonStyle = _reflection.GeneratedProtocolMessageType('ReasonStyle', (_message.Message,), {
  'DESCRIPTOR' : _REASONSTYLE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ReasonStyle)
  })
_sym_db.RegisterMessage(ReasonStyle)

RecDislike = _reflection.GeneratedProtocolMessageType('RecDislike', (_message.Message,), {
  'DESCRIPTOR' : _RECDISLIKE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.RecDislike)
  })
_sym_db.RegisterMessage(RecDislike)

RecThreePoint = _reflection.GeneratedProtocolMessageType('RecThreePoint', (_message.Message,), {
  'DESCRIPTOR' : _RECTHREEPOINT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.RecThreePoint)
  })
_sym_db.RegisterMessage(RecThreePoint)

Relate = _reflection.GeneratedProtocolMessageType('Relate', (_message.Message,), {
  'DESCRIPTOR' : _RELATE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Relate)
  })
_sym_db.RegisterMessage(Relate)

RelateItem = _reflection.GeneratedProtocolMessageType('RelateItem', (_message.Message,), {
  'DESCRIPTOR' : _RELATEITEM,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.RelateItem)
  })
_sym_db.RegisterMessage(RelateItem)

RelateTab = _reflection.GeneratedProtocolMessageType('RelateTab', (_message.Message,), {
  'DESCRIPTOR' : _RELATETAB,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.RelateTab)
  })
_sym_db.RegisterMessage(RelateTab)

ReqUser = _reflection.GeneratedProtocolMessageType('ReqUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUSER,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ReqUser)
  })
_sym_db.RegisterMessage(ReqUser)

Restriction = _reflection.GeneratedProtocolMessageType('Restriction', (_message.Message,), {
  'DESCRIPTOR' : _RESTRICTION,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Restriction)
  })
_sym_db.RegisterMessage(Restriction)

Season = _reflection.GeneratedProtocolMessageType('Season', (_message.Message,), {
  'DESCRIPTOR' : _SEASON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Season)
  })
_sym_db.RegisterMessage(Season)

SeasonPlayer = _reflection.GeneratedProtocolMessageType('SeasonPlayer', (_message.Message,), {
  'DESCRIPTOR' : _SEASONPLAYER,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.SeasonPlayer)
  })
_sym_db.RegisterMessage(SeasonPlayer)

SeasonReply = _reflection.GeneratedProtocolMessageType('SeasonReply', (_message.Message,), {
  'DESCRIPTOR' : _SEASONREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.SeasonReply)
  })
_sym_db.RegisterMessage(SeasonReply)

SeasonReq = _reflection.GeneratedProtocolMessageType('SeasonReq', (_message.Message,), {
  'DESCRIPTOR' : _SEASONREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.SeasonReq)
  })
_sym_db.RegisterMessage(SeasonReq)

Section = _reflection.GeneratedProtocolMessageType('Section', (_message.Message,), {
  'DESCRIPTOR' : _SECTION,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Section)
  })
_sym_db.RegisterMessage(Section)

ShortFormVideoDownloadReply = _reflection.GeneratedProtocolMessageType('ShortFormVideoDownloadReply', (_message.Message,), {
  'DESCRIPTOR' : _SHORTFORMVIDEODOWNLOADREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ShortFormVideoDownloadReply)
  })
_sym_db.RegisterMessage(ShortFormVideoDownloadReply)

ShortFormVideoDownloadReq = _reflection.GeneratedProtocolMessageType('ShortFormVideoDownloadReq', (_message.Message,), {
  'DESCRIPTOR' : _SHORTFORMVIDEODOWNLOADREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ShortFormVideoDownloadReq)
  })
_sym_db.RegisterMessage(ShortFormVideoDownloadReq)

SpecialCell = _reflection.GeneratedProtocolMessageType('SpecialCell', (_message.Message,), {
  'DESCRIPTOR' : _SPECIALCELL,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.SpecialCell)
  })
_sym_db.RegisterMessage(SpecialCell)

Staff = _reflection.GeneratedProtocolMessageType('Staff', (_message.Message,), {
  'DESCRIPTOR' : _STAFF,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Staff)
  })
_sym_db.RegisterMessage(Staff)

StandardCard = _reflection.GeneratedProtocolMessageType('StandardCard', (_message.Message,), {
  'DESCRIPTOR' : _STANDARDCARD,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.StandardCard)
  })
_sym_db.RegisterMessage(StandardCard)

TFPanelCustomized = _reflection.GeneratedProtocolMessageType('TFPanelCustomized', (_message.Message,), {

  'SubPanelEntry' : _reflection.GeneratedProtocolMessageType('SubPanelEntry', (_message.Message,), {
    'DESCRIPTOR' : _TFPANELCUSTOMIZED_SUBPANELENTRY,
    '__module__' : 'bilibili.app.view.v1.view_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.TFPanelCustomized.SubPanelEntry)
    })
  ,
  'DESCRIPTOR' : _TFPANELCUSTOMIZED,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.TFPanelCustomized)
  })
_sym_db.RegisterMessage(TFPanelCustomized)
_sym_db.RegisterMessage(TFPanelCustomized.SubPanelEntry)

TIcon = _reflection.GeneratedProtocolMessageType('TIcon', (_message.Message,), {
  'DESCRIPTOR' : _TICON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.TIcon)
  })
_sym_db.RegisterMessage(TIcon)

Tab = _reflection.GeneratedProtocolMessageType('Tab', (_message.Message,), {
  'DESCRIPTOR' : _TAB,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Tab)
  })
_sym_db.RegisterMessage(Tab)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Tag)
  })
_sym_db.RegisterMessage(Tag)

UgcSeason = _reflection.GeneratedProtocolMessageType('UgcSeason', (_message.Message,), {
  'DESCRIPTOR' : _UGCSEASON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UgcSeason)
  })
_sym_db.RegisterMessage(UgcSeason)

UgcSeasonStat = _reflection.GeneratedProtocolMessageType('UgcSeasonStat', (_message.Message,), {
  'DESCRIPTOR' : _UGCSEASONSTAT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UgcSeasonStat)
  })
_sym_db.RegisterMessage(UgcSeasonStat)

UpAct = _reflection.GeneratedProtocolMessageType('UpAct', (_message.Message,), {
  'DESCRIPTOR' : _UPACT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UpAct)
  })
_sym_db.RegisterMessage(UpAct)

UpLikeImg = _reflection.GeneratedProtocolMessageType('UpLikeImg', (_message.Message,), {
  'DESCRIPTOR' : _UPLIKEIMG,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UpLikeImg)
  })
_sym_db.RegisterMessage(UpLikeImg)

UpperInfos = _reflection.GeneratedProtocolMessageType('UpperInfos', (_message.Message,), {
  'DESCRIPTOR' : _UPPERINFOS,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UpperInfos)
  })
_sym_db.RegisterMessage(UpperInfos)

UserGarb = _reflection.GeneratedProtocolMessageType('UserGarb', (_message.Message,), {
  'DESCRIPTOR' : _USERGARB,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UserGarb)
  })
_sym_db.RegisterMessage(UserGarb)

UserSeason = _reflection.GeneratedProtocolMessageType('UserSeason', (_message.Message,), {
  'DESCRIPTOR' : _USERSEASON,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.UserSeason)
  })
_sym_db.RegisterMessage(UserSeason)

VideoGuide = _reflection.GeneratedProtocolMessageType('VideoGuide', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOGUIDE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.VideoGuide)
  })
_sym_db.RegisterMessage(VideoGuide)

VideoPoint = _reflection.GeneratedProtocolMessageType('VideoPoint', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOPOINT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.VideoPoint)
  })
_sym_db.RegisterMessage(VideoPoint)

VideoShot = _reflection.GeneratedProtocolMessageType('VideoShot', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOSHOT,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.VideoShot)
  })
_sym_db.RegisterMessage(VideoShot)

ViewMaterial = _reflection.GeneratedProtocolMessageType('ViewMaterial', (_message.Message,), {
  'DESCRIPTOR' : _VIEWMATERIAL,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewMaterial)
  })
_sym_db.RegisterMessage(ViewMaterial)

ViewPage = _reflection.GeneratedProtocolMessageType('ViewPage', (_message.Message,), {
  'DESCRIPTOR' : _VIEWPAGE,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewPage)
  })
_sym_db.RegisterMessage(ViewPage)

ViewProgressReply = _reflection.GeneratedProtocolMessageType('ViewProgressReply', (_message.Message,), {
  'DESCRIPTOR' : _VIEWPROGRESSREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewProgressReply)
  })
_sym_db.RegisterMessage(ViewProgressReply)

ViewProgressReq = _reflection.GeneratedProtocolMessageType('ViewProgressReq', (_message.Message,), {
  'DESCRIPTOR' : _VIEWPROGRESSREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewProgressReq)
  })
_sym_db.RegisterMessage(ViewProgressReq)

ViewReply = _reflection.GeneratedProtocolMessageType('ViewReply', (_message.Message,), {

  'TIconEntry' : _reflection.GeneratedProtocolMessageType('TIconEntry', (_message.Message,), {
    'DESCRIPTOR' : _VIEWREPLY_TICONENTRY,
    '__module__' : 'bilibili.app.view.v1.view_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewReply.TIconEntry)
    })
  ,
  'DESCRIPTOR' : _VIEWREPLY,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewReply)
  })
_sym_db.RegisterMessage(ViewReply)
_sym_db.RegisterMessage(ViewReply.TIconEntry)

ViewReq = _reflection.GeneratedProtocolMessageType('ViewReq', (_message.Message,), {
  'DESCRIPTOR' : _VIEWREQ,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.ViewReq)
  })
_sym_db.RegisterMessage(ViewReq)

Vip = _reflection.GeneratedProtocolMessageType('Vip', (_message.Message,), {
  'DESCRIPTOR' : _VIP,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.Vip)
  })
_sym_db.RegisterMessage(Vip)

VipLabel = _reflection.GeneratedProtocolMessageType('VipLabel', (_message.Message,), {
  'DESCRIPTOR' : _VIPLABEL,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.VipLabel)
  })
_sym_db.RegisterMessage(VipLabel)

subTFPanel = _reflection.GeneratedProtocolMessageType('subTFPanel', (_message.Message,), {
  'DESCRIPTOR' : _SUBTFPANEL,
  '__module__' : 'bilibili.app.view.v1.view_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.view.v1.subTFPanel)
  })
_sym_db.RegisterMessage(subTFPanel)

_VIEW = DESCRIPTOR.services_by_name['View']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TFPANELCUSTOMIZED_SUBPANELENTRY._options = None
  _TFPANELCUSTOMIZED_SUBPANELENTRY._serialized_options = b'8\001'
  _VIEWREPLY_TICONENTRY._options = None
  _VIEWREPLY_TICONENTRY._serialized_options = b'8\001'
  _BIZTYPE._serialized_start=18800
  _BIZTYPE._serialized_end=18945
  _DESCTYPE._serialized_start=18947
  _DESCTYPE._serialized_end=19012
  _ECODE._serialized_start=19014
  _ECODE._serialized_end=19047
  _MATERIALSOURCE._serialized_start=19049
  _MATERIALSOURCE._serialized_end=19090
  _OPERATIONCARDTYPE._serialized_start=19092
  _OPERATIONCARDTYPE._serialized_end=19169
  _PLAYERCARDTYPE._serialized_start=19172
  _PLAYERCARDTYPE._serialized_end=19322
  _SEASONTYPE._serialized_start=19324
  _SEASONTYPE._serialized_end=19369
  _TABOTYPE._serialized_start=19371
  _TABOTYPE._serialized_end=19421
  _TABSTYLE._serialized_start=19423
  _TABSTYLE._serialized_end=19470
  _ACTIVITYRESOURCE._serialized_start=174
  _ACTIVITYRESOURCE._serialized_end=381
  _ACTIVITYSEASON._serialized_start=384
  _ACTIVITYSEASON._serialized_end=1719
  _ADINFO._serialized_start=1722
  _ADINFO._serialized_end=1873
  _ADDCONTRACTREQ._serialized_start=1875
  _ADDCONTRACTREQ._serialized_end=1935
  _ASSET._serialized_start=1938
  _ASSET._serialized_end=2072
  _ASSETMSG._serialized_start=2074
  _ASSETMSG._serialized_end=2114
  _ATTENTION._serialized_start=2116
  _ATTENTION._serialized_end=2195
  _AUDIO._serialized_start=2198
  _AUDIO._serialized_end=2352
  _BGM._serialized_start=2354
  _BGM._serialized_end=2448
  _BIZFAVSEASONPARAM._serialized_start=2450
  _BIZFAVSEASONPARAM._serialized_end=2488
  _BIZFOLLOWVIDEOPARAM._serialized_start=2490
  _BIZFOLLOWVIDEOPARAM._serialized_end=2530
  _BIZJUMPLINKPARAM._serialized_start=2532
  _BIZJUMPLINKPARAM._serialized_end=2563
  _BIZRESERVEACTIVITYPARAM._serialized_start=2565
  _BIZRESERVEACTIVITYPARAM._serialized_end=2672
  _BIZRESERVEGAMEPARAM._serialized_start=2674
  _BIZRESERVEGAMEPARAM._serialized_end=2712
  _BUTTON._serialized_start=2714
  _BUTTON._serialized_end=2750
  _BUZZWORDCONFIG._serialized_start=2753
  _BUZZWORDCONFIG._serialized_end=2938
  _CM._serialized_start=2940
  _CM._serialized_end=2990
  _CMCONFIG._serialized_start=2992
  _CMCONFIG._serialized_end=3045
  _CACHEVIEWREPLY._serialized_start=3048
  _CACHEVIEWREPLY._serialized_end=3676
  _CACHEVIEWREQ._serialized_start=3678
  _CACHEVIEWREQ._serialized_end=3803
  _CHRONOS._serialized_start=3805
  _CHRONOS._serialized_end=3855
  _CHRONOSPKGREQ._serialized_start=3857
  _CHRONOSPKGREQ._serialized_end=3943
  _CLICKACTIVITYSEASONREQ._serialized_start=3946
  _CLICKACTIVITYSEASONREQ._serialized_end=4196
  _CLICKPLAYERCARDREQ._serialized_start=4198
  _CLICKPLAYERCARDREQ._serialized_end=4287
  _CMIPAD._serialized_start=4290
  _CMIPAD._serialized_end=4461
  _COMMANDDM._serialized_start=4464
  _COMMANDDM._serialized_end=4625
  _CONFIG._serialized_start=4628
  _CONFIG._serialized_end=4880
  _CONTRACTCARD._serialized_start=4883
  _CONTRACTCARD._serialized_end=5201
  _CONTRACTTEXT._serialized_start=5203
  _CONTRACTTEXT._serialized_end=5272
  _CREATIVECONTENT._serialized_start=5275
  _CREATIVECONTENT._serialized_end=5508
  _CUSTOMCONFIG._serialized_start=5510
  _CUSTOMCONFIG._serialized_end=5546
  _DM._serialized_start=5548
  _DM._serialized_end=5602
  _DESCV2._serialized_start=5604
  _DESCV2._serialized_end=5698
  _DISLIKE._serialized_start=5700
  _DISLIKE._serialized_end=5797
  _DISLIKEREASONS._serialized_start=5799
  _DISLIKEREASONS._serialized_end=5883
  _ELECRANK._serialized_start=5885
  _ELECRANK._serialized_end=5960
  _ELECRANKITEM._serialized_start=5962
  _ELECRANKITEM._serialized_end=6040
  _EPISODE._serialized_start=6043
  _EPISODE._serialized_end=6318
  _EXPOSEPLAYERCARDREQ._serialized_start=6320
  _EXPOSEPLAYERCARDREQ._serialized_end=6439
  _FEEDVIEWITEM._serialized_start=6441
  _FEEDVIEWITEM._serialized_end=6547
  _FEEDVIEWREPLY._serialized_start=6549
  _FEEDVIEWREPLY._serialized_end=6632
  _FEEDVIEWREQ._serialized_start=6635
  _FEEDVIEWREQ._serialized_end=6878
  _HISTORY._serialized_start=6880
  _HISTORY._serialized_end=6920
  _HONOR._serialized_start=6923
  _HONOR._serialized_end=7117
  _INTERACTION._serialized_start=7120
  _INTERACTION._serialized_end=7253
  _LABEL._serialized_start=7255
  _LABEL._serialized_end=7364
  _LIKECUSTOM._serialized_start=7366
  _LIKECUSTOM._serialized_end=7479
  _LIVE._serialized_start=7481
  _LIVE._serialized_end=7550
  _LIVEORDERINFO._serialized_start=7552
  _LIVEORDERINFO._serialized_end=7643
  _NOREPLY._serialized_start=7645
  _NOREPLY._serialized_end=7654
  _NODE._serialized_start=7656
  _NODE._serialized_end=7707
  _NOTICE._serialized_start=7709
  _NOTICE._serialized_end=7746
  _OFFICIALVERIFY._serialized_start=7748
  _OFFICIALVERIFY._serialized_end=7792
  _ONLINE._serialized_start=7794
  _ONLINE._serialized_end=7851
  _ONWEREXT._serialized_start=7854
  _ONWEREXT._serialized_end=8059
  _OPERATIONCARD._serialized_start=8062
  _OPERATIONCARD._serialized_end=8195
  _OPERATIONCARDNEW._serialized_start=8198
  _OPERATIONCARDNEW._serialized_end=8749
  _OPERATIONRELATE._serialized_start=8752
  _OPERATIONRELATE._serialized_end=8893
  _ORDER._serialized_start=8896
  _ORDER._serialized_end=9252
  _PACKINFO._serialized_start=9254
  _PACKINFO._serialized_end=9292
  _PLAYERICON._serialized_start=9294
  _PLAYERICON._serialized_end=9364
  _POINTMATERIAL._serialized_start=9366
  _POINTMATERIAL._serialized_end=9419
  _RANK._serialized_start=9421
  _RANK._serialized_end=9475
  _REASONSTYLE._serialized_start=9478
  _REASONSTYLE._serialized_end=9679
  _RECDISLIKE._serialized_start=9682
  _RECDISLIKE._serialized_end=9900
  _RECTHREEPOINT._serialized_start=9903
  _RECTHREEPOINT._serialized_end=10042
  _RELATE._serialized_start=10045
  _RELATE._serialized_end=10887
  _RELATEITEM._serialized_start=10889
  _RELATEITEM._serialized_end=10929
  _RELATETAB._serialized_start=10931
  _RELATETAB._serialized_end=10969
  _REQUSER._serialized_start=10972
  _REQUSER._serialized_end=11133
  _RESTRICTION._serialized_start=11135
  _RESTRICTION._serialized_end=11231
  _SEASON._serialized_start=11234
  _SEASON._serialized_end=11564
  _SEASONPLAYER._serialized_start=11566
  _SEASONPLAYER._serialized_end=11633
  _SEASONREPLY._serialized_start=11635
  _SEASONREPLY._serialized_end=11697
  _SEASONREQ._serialized_start=11699
  _SEASONREQ._serialized_end=11729
  _SECTION._serialized_start=11731
  _SECTION._serialized_end=11830
  _SHORTFORMVIDEODOWNLOADREPLY._serialized_start=11833
  _SHORTFORMVIDEODOWNLOADREPLY._serialized_end=11966
  _SHORTFORMVIDEODOWNLOADREQ._serialized_start=11969
  _SHORTFORMVIDEODOWNLOADREQ._serialized_end=12204
  _SPECIALCELL._serialized_start=12207
  _SPECIALCELL._serialized_end=12455
  _STAFF._serialized_start=12458
  _STAFF._serialized_end=12664
  _STANDARDCARD._serialized_start=12666
  _STANDARDCARD._serialized_end=12771
  _TFPANELCUSTOMIZED._serialized_start=12774
  _TFPANELCUSTOMIZED._serialized_end=13089
  _TFPANELCUSTOMIZED_SUBPANELENTRY._serialized_start=13008
  _TFPANELCUSTOMIZED_SUBPANELENTRY._serialized_end=13089
  _TICON._serialized_start=13091
  _TICON._serialized_end=13112
  _TAB._serialized_start=13115
  _TAB._serialized_end=13391
  _TAG._serialized_start=13393
  _TAG._serialized_end=13515
  _UGCSEASON._serialized_start=13518
  _UGCSEASON._serialized_end=13941
  _UGCSEASONSTAT._serialized_start=13944
  _UGCSEASONSTAT._serialized_end=14116
  _UPACT._serialized_start=14118
  _UPACT._serialized_end=14229
  _UPLIKEIMG._serialized_start=14231
  _UPLIKEIMG._serialized_end=14293
  _UPPERINFOS._serialized_start=14295
  _UPPERINFOS._serialized_end=14411
  _USERGARB._serialized_start=14413
  _USERGARB._serialized_end=14450
  _USERSEASON._serialized_start=14452
  _USERSEASON._serialized_end=14483
  _VIDEOGUIDE._serialized_start=14486
  _VIDEOGUIDE._serialized_end=14791
  _VIDEOPOINT._serialized_start=14793
  _VIDEOPOINT._serialized_end=14895
  _VIDEOSHOT._serialized_start=14897
  _VIDEOSHOT._serialized_end=15018
  _VIEWMATERIAL._serialized_start=15020
  _VIEWMATERIAL._serialized_end=15109
  _VIEWPAGE._serialized_start=15112
  _VIEWPAGE._serialized_end=15300
  _VIEWPROGRESSREPLY._serialized_start=15303
  _VIEWPROGRESSREPLY._serialized_end=15676
  _VIEWPROGRESSREQ._serialized_start=15679
  _VIEWPROGRESSREQ._serialized_end=15809
  _VIEWREPLY._serialized_start=15812
  _VIEWREPLY._serialized_end=18038
  _VIEWREPLY_TICONENTRY._serialized_start=17965
  _VIEWREPLY_TICONENTRY._serialized_end=18038
  _VIEWREQ._serialized_start=18041
  _VIEWREQ._serialized_end=18387
  _VIP._serialized_start=18390
  _VIP._serialized_end=18582
  _VIPLABEL._serialized_start=18584
  _VIPLABEL._serialized_end=18643
  _SUBTFPANEL._serialized_start=18646
  _SUBTFPANEL._serialized_end=18797
  _VIEW._serialized_start=19473
  _VIEW._serialized_end=20474
# @@protoc_insertion_point(module_scope)



import hashlib
import random
from typing import Optional

from ..._typing import T_Auth
from ..protos.bilibili.metadata.device.device_pb2 import Device
from ..protos.bilibili.metadata.locale.locale_pb2 import Locale
from ..protos.bilibili.metadata.metadata_pb2 import Metadata
from ..protos.bilibili.metadata.network.network_pb2 import Network, NetworkType


def fake_buvid():
    mac_list = []
    for _ in range(1, 7):
        rand_str = "".join(random.sample("0123456789abcdef", 2))
        mac_list.append(rand_str)
    rand_mac = ":".join(mac_list)
    md5 = hashlib.md5()
    md5.update(rand_mac.encode())
    md5_mac_str = md5.hexdigest()
    md5_mac = list(md5_mac_str)
    fake_mac = ("XY" + md5_mac[2] + md5_mac[12] + md5_mac[22] + md5_mac_str).upper()
    return fake_mac


BUVID = fake_buvid()


def make_metadata(auth: T_Auth = None, access_key: Optional[str] = None):
    if not access_key and auth:
        from ...auth import Auth

        access_key = Auth(auth).access_token
    device_params = {
        "mobi_app": "android",
        "device": "phone",
        "build": 6550400,
        "channel": "bili",
        "buvid": BUVID,
        "platform": "android",
    }
    metadata_params = device_params.copy()
    if access_key:
        metadata_params["access_key"] = access_key
    metadata = {
        "x-bili-device-bin": Device(**device_params).SerializeToString(),
        "x-bili-local-bin": Locale().SerializeToString(),
        "x-bili-metadata-bin": Metadata(**metadata_params).SerializeToString(),
        "x-bili-network-bin": Network(type=NetworkType.WIFI).SerializeToString(),
    }
    if access_key:
        metadata["authorization"] = f"identify_v1 {access_key}".encode()
    return tuple(metadata.items())
